# WAFFLE Development
- Reference Figure
- Load font style, figure dimensions, default rules from `matplotlibrc` file
- Dynamic panel configuration from data alone
- Return figure object for further customization after automatically generating it
- Automatically install Inter font? (need to check liscense)
- Generate IPCC color maps